#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-streams
version:              0.8.9.9
visibility:           public
id:                   http-streams-0.8.9.9-FobiuySKdX32R9FaVkQDp9
key:                  http-streams-0.8.9.9-FobiuySKdX32R9FaVkQDp9
license:              BSD-3-Clause
copyright:            © 2012-2023 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-streams/
synopsis:             An HTTP client using io-streams
description:
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    handle the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.

    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.

category:             Web, IO-Streams
abi:                  6ebf27d8ac80830e0792474f6d2a1235
exposed:              True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser

hidden-modules:       Network.Http.Utilities
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-streams
hs-libraries:         HShttp-streams-0.8.9.9-FobiuySKdX32R9FaVkQDp9
depends:
    HsOpenSSL-0.11.7.9-nkYimBP6b58hlFFR12MyK
    aeson-2.2.1.0-7GSyYSIvS9RDNhRsQEr5uY
    attoparsec-0.14.4-4MFXwr0rahYLyPRJgVlAQG
    attoparsec-aeson-2.2.0.0-nc9R3aQPcgIMzEKoEkyHN base-4.18.2.1
    base64-bytestring-1.2.1.0-94mbkUjIRhx4LxftIrWkbN
    blaze-builder-0.4.4.1-JLqPtDx7HxAPtE5yCjd2z bytestring-0.11.5.3
    case-insensitive-1.2.1.0-JZ3hGp6UuW4CjEwd4EXTon directory-1.3.8.5
    filepath-1.4.300.1 http-common-0.8.3.4-ENxC3wbvjwP1VlPtkXZfcv
    io-streams-1.5.2.2-I0OE2eahdadBwNixYH5cuA mtl-2.3.1
    network-3.1.4.0-1H1Z94H5H3Y4XT8Ragei31
    network-uri-2.6.4.2-BVE1W1vAZdgLmRmXOrcj1y
    openssl-streams-1.2.3.0-Dt6lC0mE7WYH4FS5UIwolk text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-KOOMDe69vyW5LNgLyOaup0

haddock-interfaces:
    /usr/share/doc/haskell-http-streams/html/http-streams.haddock

haddock-html:         /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

